@@ -12,9 +12,13 @@ beyond plotting. Please see a full histogram library like boost-histogram or
 hist.
 """
 
+from __future__ import annotations
+
 import abc
 import enum
-from typing import TYPE_CHECKING, Any, Iterator, Optional, Sequence, Tuple, Union, cast
+import typing
+from collections.abc import Iterator, Sequence
+from typing import TYPE_CHECKING, Any
 
 import numpy as np
 
@@ -45,11 +49,11 @@ class Traits:
 
 
 if TYPE_CHECKING:
-    _traits: PlottableTraits = cast(Traits, None)
+    _traits: PlottableTraits = typing.cast(Traits, None)
 
 
 class NumPyPlottableAxis:
-    def __init__(self, edges: "np.typing.NDArray[Any]") -> None:
+    def __init__(self, edges: np.typing.NDArray[Any]) -> None:
         """
         The vals should already be an Nx2 ndarray of edges.
         """
@@ -65,7 +69,7 @@ class NumPyPlottableAxis:
 
         return f"{self.__class__.__name__}({self.edges!r})"
 
-    def __getitem__(self, index: int) -> Tuple[float, float]:
+    def __getitem__(self, index: int) -> tuple[float, float]:
         """
         Get the pair of edges (not discrete) or bin label (discrete).
         """
@@ -85,7 +89,7 @@ class NumPyPlottableAxis:
         """
         return np.allclose(self.edges, other.edges)
 
-    def __iter__(self) -> Iterator[Tuple[float, float]]:
+    def __iter__(self) -> Iterator[tuple[float, float]]:
         """
         A useful part of the Protocol for easy access by plotters.
         """
@@ -93,12 +97,12 @@ class NumPyPlottableAxis:
 
 
 if TYPE_CHECKING:
-    _axis: PlottableAxisGeneric[Tuple[float, float]] = cast(NumPyPlottableAxis, None)
+    _axis: PlottableAxisGeneric[tuple[float, float]] = typing.cast(
+        NumPyPlottableAxis, None
+    )
 
 
-def _bin_helper(
-    shape: int, bins: Optional["np.typing.NDArray[Any]"]
-) -> NumPyPlottableAxis:
+def _bin_helper(shape: int, bins: np.typing.NDArray[Any] | None) -> NumPyPlottableAxis:
     """
     Returns a axis built from the input bins array, which can be None (0 to N),
     2D lower, upper edges), or 1D (N+1 in length).
@@ -107,29 +111,24 @@ def _bin_helper(
         return NumPyPlottableAxis(
             np.array([np.arange(0, shape), np.arange(1, shape + 1)]).T
         )
-    elif bins.ndim == 2:
+    if bins.ndim == 2:
         return NumPyPlottableAxis(bins)
-    elif bins.ndim == 1:
+    if bins.ndim == 1:
         return NumPyPlottableAxis(np.array([bins[:-1], bins[1:]]).T)
-    else:
-        raise ValueError(
-            "Bins not understood, should be 2d array of min/max edges or 1D array of edges or None"
-        )
+    msg = "Bins not understood, should be 2d array of min/max edges or 1D array of edges or None"
+    raise ValueError(msg)
 
 
 class NumPyPlottableHistogram:
     def __init__(
         self,
-        hist: "np.typing.NDArray[Any]",
-        *bins: Union[
-            "np.typing.NDArray[Any]",
-            None,
-            Tuple[Union["np.typing.NDArray[Any]", None], ...],
-        ],
-        variances: Optional["np.typing.NDArray[Any]"] = None,
+        hist: np.typing.NDArray[Any],
+        *bins: (
+            np.typing.NDArray[Any] | None | tuple[np.typing.NDArray[Any] | None, ...]
+        ),
+        variances: np.typing.NDArray[Any] | None = None,
         kind: Kind = Kind.COUNT,
     ) -> None:
-
         self._values = hist
         self._variances = variances
 
@@ -152,32 +151,31 @@ class NumPyPlottableHistogram:
         axes = ", ".join(repr(s) for s in self.axes)
         return f"{self.__class__.__name__}({self._values!r}, <{axes}>)"
 
-    def values(self) -> "np.typing.NDArray[Any]":
+    def values(self) -> np.typing.NDArray[Any]:
         return self._values
 
-    def counts(self) -> "np.typing.NDArray[Any]":
+    def counts(self) -> np.typing.NDArray[Any]:
         return self._values
 
-    def variances(self) -> Optional["np.typing.NDArray[Any]"]:
+    def variances(self) -> np.typing.NDArray[Any] | None:
         return self._variances
 
 
 if TYPE_CHECKING:
     # Verify that the above class is a valid PlottableHistogram
-    _: PlottableHistogram = cast(NumPyPlottableHistogram, None)
+    _: PlottableHistogram = typing.cast(NumPyPlottableHistogram, None)
 
 
 def _roottarray_asnumpy(
-    tarr: Any, shape: Optional[Tuple[int, ...]] = None
-) -> "np.typing.NDArray[Any]":
+    tarr: Any, shape: tuple[int, ...] | None = None
+) -> np.typing.NDArray[Any]:
     llv = tarr.GetArray()
-    arr: "np.typing.NDArray[Any]" = np.frombuffer(
+    arr: np.typing.NDArray[Any] = np.frombuffer(
         llv, dtype=llv.typecode, count=tarr.GetSize()
     )
     if shape is not None:
         return np.reshape(arr, shape, order="F")
-    else:
-        return arr
+    return arr
 
 
 class ROOTAxis(abc.ABC):
@@ -199,15 +197,14 @@ class ROOTAxis(abc.ABC):
         )
 
     @abc.abstractmethod
-    def __iter__(self) -> Union[Iterator[Tuple[float, float]], Iterator[str]]:
+    def __iter__(self) -> Iterator[tuple[float, float]] | Iterator[str]:
         pass
 
     @staticmethod
-    def create(tAx: Any) -> Union["DiscreteROOTAxis", "ContinuousROOTAxis"]:
+    def create(tAx: Any) -> DiscreteROOTAxis | ContinuousROOTAxis:
         if all(tAx.GetBinLabel(i + 1) for i in range(tAx.GetNbins())):
             return DiscreteROOTAxis(tAx)
-        else:
-            return ContinuousROOTAxis(tAx)
+        return ContinuousROOTAxis(tAx)
 
 
 class ContinuousROOTAxis(ROOTAxis):
@@ -215,10 +212,10 @@ class ContinuousROOTAxis(ROOTAxis):
     def traits(self) -> PlottableTraits:
         return Traits(circular=False, discrete=False)
 
-    def __getitem__(self, index: int) -> Tuple[float, float]:
+    def __getitem__(self, index: int) -> tuple[float, float]:
         return (self.tAx.GetBinLowEdge(index + 1), self.tAx.GetBinUpEdge(index + 1))
 
-    def __iter__(self) -> Iterator[Tuple[float, float]]:
+    def __iter__(self) -> Iterator[tuple[float, float]]:
         for i in range(len(self)):
             yield self[i]
 
@@ -242,10 +239,10 @@ class ROOTPlottableHistBase:
     def __init__(self, thist: Any) -> None:
         self.thist: Any = thist
         nDim = thist.GetDimension()
-        self._shape: Tuple[int, ...] = tuple(
+        self._shape: tuple[int, ...] = tuple(
             getattr(thist, f"GetNbins{ax}")() + 2 for ax in "XYZ"[:nDim]
         )
-        self.axes: Tuple[Union[ContinuousROOTAxis, DiscreteROOTAxis], ...] = tuple(
+        self.axes: tuple[ContinuousROOTAxis | DiscreteROOTAxis, ...] = tuple(
             ROOTAxis.create(getattr(thist, f"Get{ax}axis")()) for ax in "XYZ"[:nDim]
         )
 
@@ -266,20 +263,19 @@ class ROOTPlottableHistogram(ROOTPlottableHistBase):
     def kind(self) -> str:
         return Kind.COUNT
 
-    def values(self) -> "np.typing.NDArray[Any]":
+    def values(self) -> np.typing.NDArray[Any]:
         return _roottarray_asnumpy(self.thist, shape=self._shape)[
             tuple([slice(1, -1)] * len(self._shape))
         ]
 
-    def variances(self) -> "np.typing.NDArray[Any]":
+    def variances(self) -> np.typing.NDArray[Any]:
         if self.hasWeights:
             return _roottarray_asnumpy(self.thist.GetSumw2(), shape=self._shape)[
                 tuple([slice(1, -1)] * len(self._shape))
             ]
-        else:
-            return self.values()
+        return self.values()
 
-    def counts(self) -> "np.typing.NDArray[Any]":
+    def counts(self) -> np.typing.NDArray[Any]:
         if not self.hasWeights:
             return self.values()
 
@@ -300,18 +296,18 @@ class ROOTPlottableProfile(ROOTPlottableHistBase):
     def kind(self) -> str:
         return Kind.MEAN
 
-    def values(self) -> "np.typing.NDArray[Any]":
+    def values(self) -> np.typing.NDArray[Any]:
         return np.array(
             [self.thist.GetBinContent(i) for i in range(self.thist.GetNcells())]
         ).reshape(self._shape, order="F")[tuple([slice(1, -1)] * len(self._shape))]
 
-    def variances(self) -> "np.typing.NDArray[Any]":
+    def variances(self) -> np.typing.NDArray[Any]:
         return (
             np.array([self.thist.GetBinError(i) for i in range(self.thist.GetNcells())])
             ** 2
         ).reshape(self._shape, order="F")[tuple([slice(1, -1)] * len(self._shape))]
 
-    def counts(self) -> "np.typing.NDArray[Any]":
+    def counts(self) -> np.typing.NDArray[Any]:
         sumw = _roottarray_asnumpy(self.thist, shape=self._shape)[
             tuple([slice(1, -1)] * len(self._shape))
         ]
@@ -331,10 +327,10 @@ class ROOTPlottableProfile(ROOTPlottableHistBase):
 
 if TYPE_CHECKING:
     # Verify that the above class is a valid PlottableHistogram
-    _axis = cast(ContinuousROOTAxis, None)
-    _axis2: PlottableAxisGeneric[str] = cast(DiscreteROOTAxis, None)
-    _ = cast(ROOTPlottableHistogram, None)
-    _ = cast(ROOTPlottableProfile, None)
+    _axis = typing.cast(ContinuousROOTAxis, None)
+    _axis2: PlottableAxisGeneric[str] = typing.cast(DiscreteROOTAxis, None)
+    _ = typing.cast(ROOTPlottableHistogram, None)
+    _ = typing.cast(ROOTPlottableProfile, None)
 
 
 def ensure_plottable_histogram(hist: Any) -> PlottableHistogram:
@@ -352,21 +348,22 @@ def ensure_plottable_histogram(hist: Any) -> PlottableHistogram:
         # Already satisfies the Protocol
         return hist
 
-    elif hasattr(hist, "to_numpy"):
+    if hasattr(hist, "to_numpy"):
         # Generic (possibly Uproot 4)
-        _tup1: Tuple["np.typing.NDArray[Any]", ...] = hist.to_numpy(flow=False)
+        _tup1: tuple[np.typing.NDArray[Any], ...] = hist.to_numpy(flow=False)
         return NumPyPlottableHistogram(*_tup1)
 
-    elif hasattr(hist, "numpy"):
+    if hasattr(hist, "numpy"):
         # uproot/TH1 - TODO: could support variances
-        _tup2: Tuple["np.typing.NDArray[Any]", ...] = hist.numpy()
+        _tup2: tuple[np.typing.NDArray[Any], ...] = hist.numpy()
         return NumPyPlottableHistogram(*_tup2)
 
-    elif isinstance(hist, tuple):
+    if isinstance(hist, tuple):
         # NumPy histogram tuple
         if len(hist) < 2:
-            raise TypeError("Can't be applied to less than 2D tuple")
-        elif (
+            msg = "Can't be applied to less than 2D tuple"
+            raise TypeError(msg)
+        if (
             len(hist) == 2
             and isinstance(hist[1], (list, tuple))
             and all(isinstance(h, np.ndarray) for h in hist[1])
@@ -375,15 +372,14 @@ def ensure_plottable_histogram(hist: Any) -> PlottableHistogram:
             return NumPyPlottableHistogram(
                 np.asarray(hist[0]), *(np.asarray(h) for h in hist[1])
             )
-        elif hist[1] is None:
+        if hist[1] is None:
             return NumPyPlottableHistogram(
                 np.asarray(hist[0]), *(None for _ in np.asarray(hist[0]).shape)
             )
-        else:
-            # Standard tuple
-            return NumPyPlottableHistogram(*(np.asarray(h) for h in hist))
+        # Standard tuple
+        return NumPyPlottableHistogram(*(np.asarray(h) for h in hist))
 
-    elif hasattr(hist, "InheritsFrom") and hist.InheritsFrom("TH1"):
+    if hasattr(hist, "InheritsFrom") and hist.InheritsFrom("TH1"):
         if any(
             hist.InheritsFrom(profCls)
             for profCls in ("TProfile", "TProfile2D", "TProfile3D")
@@ -392,5 +388,5 @@ def ensure_plottable_histogram(hist: Any) -> PlottableHistogram:
 
         return ROOTPlottableHistogram(hist)
 
-    else:
-        raise TypeError(f"Can't be used on this type of object: {hist!r}")
+    msg = f"Can't be used on this type of object: {hist!r}"
+    raise TypeError(msg)
